@@ -8,6 +8,7 @@ from bw2data.io import EcospoldImporter, EcospoldImpactAssessmentImporter
 from flask import Flask, url_for, render_template, request, redirect, abort
 from fuzzywuzzy import process
 from jobs import JobDispatch, InvalidJob
+from urllib import unquote as _unquote
 from utils import get_job_id, get_job, set_job_status, json_response
 import itertools
 import json
@@ -16,6 +17,17 @@ import os
 import urllib2
 
 
+def jqfilepicker_unquote(source):
+    """
+Stupid Javascript (insert joke here...) and jQueryFilePicker
+http://stackoverflow.com/questions/300445/how-to-unquote-a-urlencoded-unicode-string-in-python
+https://github.com/simogeo/Filemanager/issues/40
+    """
+    result = _unquote(source)
+    if '%u' in result:
+        result = result.replace('%u', '\\u').decode('unicode_escape')
+    return result
+
 app = Flask(__name__)
 
 ###########################
@@ -69,13 +81,17 @@ def fp_test():
 @app.route("/fp-api", methods=["POST"])
 def fp_api():
     full = bool(request.args.get("full", False))
-    path = urllib2.unquote(request.form["dir"])
+    path = jqfilepicker_unquote(request.form["dir"])
     try:
         root, dirs, files = os.walk(path).next()
     except StopIteration:
-        # Only files from now on...
-        root, dirs = path, []
-        files = os.listdir(root)
+        try:
+            # Only files from now on...
+            root, dirs = path, []
+            files = os.listdir(root)
+        except:
+            # Don't have permissions for this directory or other OS error
+            files = []
     data = []
     files = [x for x in files if x[0] != "."]
     if not full and len(files) > 20:
@@ -87,14 +103,14 @@ def fp_api():
             "dir": True,
             "path": os.path.join(root, dir_name),
             "name": dir_name
-            })
+        })
     for file_name in files:
         data.append({
             "dir": False,
             "ext": file_name.split(".")[-1].lower(),
             "path": os.path.join(root, file_name),
             "name": file_name
-            })
+        })
     return render_template("fp-select.html", dirtree=data)
 
 #######################
@@ -112,16 +128,13 @@ def set_path():
 
 @app.route('/start/biosphere')
 def install_biosphere():
-    setup()
+    bw2setup()
     return "1"
 
 
 @app.route('/start')
 def start():
-    return render_template("start.html")
-    """
-    You are currently saving your work in a temporary directory that can be deleted at any time. You can let Brightway2 create a workspace in your home directory, or you can specify a different directory by typing in the full path below:
-    """
+    return render_template("start.html", root_path=json.dumps(os.path.abspath("/")))
 
 #################
 ### Importing ###
